function Examples_web


% -------------------------------------------------

[h0,h1,h2,z0,z1,z2] = MakeFilters(1,3);
h1 = -h1;
[h0' h1' h2']
plot_web(h0,h1,h2,z0,z1,z2);

figure(1)
print -depsc 'figures/W13'

figure(2)
print -depsc 'figures/W13b'


% -------------------------------------------------

[h0,h1,h2,z0,z1,z2] = MakeFilters(1,4,'mid');
[h0' h1' h2']
plot_web(h0,h1,h2,z0,z1,z2);

figure(1)
print -depsc 'figures/W14'

figure(2)
print -depsc 'figures/W14b'

% ---------------------------------------------------

% Make Biframe Example

[h0,h1,h2,h0_,h1_,h2_,z0,z1,z2,z0_,z1_,z2_] = MakeBiframe;

[h0' h1' h2']
plot_web(h0,h1,h2,z0,z1,z2);
figure(1)
print -depsc 'figures/W14_anal'

[h0_' h1_' h2_']
plot_web(h0_,h1_,h2_,z0_,z1_,z2_);
figure(1)
print -depsc 'figures/W14_synth'



% ---------------------------------------------------
% ---------------------------------------------------
% ---------------------------------------------------



function plot_web(h0,h1,h2,z0,z1,z2)

if nargin < 4, z0 = roots(h0); end
if nargin < 5, z1 = roots(h1); end
if nargin < 6, z2 = roots(h2); end

[w1,s,t] = wletfn(h0,h1);
[w2,s,t] = wletfn(h0,h2);
N = length(h0);

fsa = 6;
R = 3;
ms = 3;
title_fs = 12; % title font size

lw = 1.5;	% linewidth
ms = 3;		% markersize

% paperposition
paperpos = [2 2 7 9];    % [left, bottom, width, height]

figure(1)
clf

ax = [-1 N -1 1.0];
subplot(R,2,1),
stem(0:N-1,h0,'filled','linewidth',lw,'markersize',ms),
axis(ax)
% set(gca,'fontsize',fsa)
title('h_0(n)','fontsize',title_fs)
subplot(R,2,3),
stem(0:N-1,h1,'filled','linewidth',lw,'markersize',ms), axis(ax)
% set(gca,'fontsize',fsa)
title('h_1(n)','fontsize',title_fs)
subplot(R,2,5),
stem(0:N-1,h2,'filled','linewidth',lw,'markersize',ms), axis(ax)
% set(gca,'fontsize',fsa)
title('h_2(n)','fontsize',title_fs)

ax0 = [0 N-1 -0.5 1.5];
ax = [0 N-1 -1 1.0];
subplot(R,2,2), plot(t,s,'linewidth',lw),  axis(ax0)
% set(gca,'fontsize',fsa)
title('\phi(t)','fontsize',title_fs)
subplot(R,2,4), plot(t,w1,'linewidth',lw), axis(ax)
% set(gca,'fontsize',fsa)
title('\psi_1(t)','fontsize',title_fs)
subplot(R,2,6), plot(t,w2,'linewidth',lw), axis(ax)
% set(gca,'fontsize',fsa)
title('\psi_2(t)','fontsize',title_fs)


set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperPosition', paperpos);


% PLOT FREQUENCY RESPONSES

figure(2)
clf

[H0,w] = freqz(h0);
[H1,w] = freqz(h1);
[H2,w] = freqz(h2);

subplot(R,2,1)
plot(w/pi,abs(H0).^2,'b',w/pi,abs(H1).^2,'g',w/pi,abs(H2).^2,'r','linewidth',lw)

% set(gca,'fontsize',8)
title('FREQUENCY RESPONSES')
xlabel('\omega/\pi')
% xlabel('\omega')
% axis([0 1 0 2.5])
% set(gca,'xtick',[0 0.25 0.5 0.75  1]);
% set(gca,'FontName','Symbol')
% set(gca,'xtickLabel',{'0','0.25 p','0.5 p','0.75 p','p'})


% ITERATED FILTERS

f{1}{1} = h0;
f{2}{1} = h1;
f{3}{1} = h2;

subplot(R,2,2)

plot(w/pi,abs(H1).^2,'g',w/pi,abs(H2).^2,'r','linewidth',lw)
hold on

J = 3;
for j = 2:J
    for i = 1:3
        f{i}{j} = conv(h0,up(f{i}{j-1},2));
    end
    [H1,w] = freqz(f{2}{j});
    [H2,w] = freqz(f{3}{j});
    plot(w/pi,abs(H1).^2,'g',w/pi,abs(H2).^2,'r','linewidth',lw)
end
[H0,w] = freqz(f{1}{j});
plot(w/pi,abs(H0).^2,'b','linewidth',lw);
title('ITERATED FREQUENCY RESPONSES')
xlabel('\omega/\pi')


set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperPosition', paperpos);









