function [s,t] = scalfn(h,J)
% [s,t] = scalfn(h,J);
% Scaling function obtained by dyadic expansion
% input
%    h : scaling filter (must have even length)
% output
%    s : samples of the scaling function phi(t)
%        for t = k/2^J, k=0,1,2,...
% example:
%    h = daub(6);
%    [s,t] = scalfn(h);
%    plot(t,s)

if nargin < 2 
   J = 5;
end

N = length(h);
h = h(:).';             % form a row vector
% h = h*sqrt(2)/sum(h);   % normalize: sum(h) = sqrt(2)

% check that sum(h(2n)) = sum(h(2n+1))
if abs(sum(h(1:2:N))-sum(h(2:2:N))) > 0.0001
   disp('   need: sum(h(2n)) = sum(h(2n+1))')
   return
end

H = convmtx(h(:),N);
M = sqrt(2)*H(1:2:2*N-1,:);
Q = M - eye(N);
Q(N,:) = ones(1,N);
s = Q \ [zeros(N-1,1); 1];
% s = [Q; ones(1,N)] \ [zeros(N,1); 1];
s = s.';                    % phi at integers
L = N;                      % length of phi vector
for k = 0:J-1
  s = sqrt(2)*conv(h,s);
  L = 2*L-1;
  s = s(1:L);
  h = up(h,2);
end
t = (0:L-1)*(N-1)/(L-1);



